@@ -206,6 +206,19 @@ Value: 'v3'. Value should be one of: v., v.",
         self.assertRaises(exc.InvalidInput, setattr, obj, 'alist', 12)
         self.assertRaises(exc.InvalidInput, setattr, obj, 'alist', [2, 'a'])
 
+    def test_attribute_validation_minimum(self):
+        class ATypeInt(object):
+            attr = types.IntegerType(minimum=1, maximum=5)
+
+        types.register_type(ATypeInt)
+
+        obj = ATypeInt()
+        obj.attr = 2
+
+        # comparison between 'zero' value and intger minimum (1) raises a
+        # TypeError which must be wrapped into an InvalidInput exception
+        self.assertRaises(exc.InvalidInput, setattr, obj, 'attr', 'zero')
+
     def test_text_attribute_conversion(self):
         class SType(object):
             atext = types.text
@@ -326,22 +339,37 @@ Value: 'v3'. Value should be one of: v., v.",
         v.validate('A')
         self.assertRaises(ValueError, v.validate, '_')
 
+    def test_validate_string_type_pattern_exception_message(self):
+        regex = '^[a-zA-Z0-9]*$'
+        v = types.StringType(pattern=regex)
+        try:
+            v.validate('_')
+            self.assertFail()
+        except ValueError as e:
+            self.assertIn(regex, str(e))
+
     def test_validate_ipv4_address_type(self):
         v = types.IPv4AddressType()
-        v.validate('127.0.0.1')
-        v.validate('192.168.0.1')
+        self.assertEqual(v.validate('127.0.0.1'), '127.0.0.1')
+        self.assertEqual(v.validate('192.168.0.1'), '192.168.0.1')
+        self.assertEqual(v.validate(u'8.8.1.1'), u'8.8.1.1')
         self.assertRaises(ValueError, v.validate, '')
         self.assertRaises(ValueError, v.validate, 'foo')
         self.assertRaises(ValueError, v.validate,
                           '2001:0db8:bd05:01d2:288a:1fc0:0001:10ee')
+        self.assertRaises(ValueError, v.validate, '1.2.3')
 
     def test_validate_ipv6_address_type(self):
         v = types.IPv6AddressType()
-        v.validate('0:0:0:0:0:0:0:1')
-        v.validate('2001:0db8:bd05:01d2:288a:1fc0:0001:10ee')
+        self.assertEqual(v.validate('0:0:0:0:0:0:0:1'),
+                         '0:0:0:0:0:0:0:1')
+        self.assertEqual(v.validate(u'0:0:0:0:0:0:0:1'), u'0:0:0:0:0:0:0:1')
+        self.assertEqual(v.validate('2001:0db8:bd05:01d2:288a:1fc0:0001:10ee'),
+                         '2001:0db8:bd05:01d2:288a:1fc0:0001:10ee')
         self.assertRaises(ValueError, v.validate, '')
         self.assertRaises(ValueError, v.validate, 'foo')
         self.assertRaises(ValueError, v.validate, '192.168.0.1')
+        self.assertRaises(ValueError, v.validate, '0:0:0:0:0:0:1')
 
     def test_validate_uuid_type(self):
         v = types.UuidType()
