@@ -361,6 +361,8 @@ class ServiceDocumenter(autodoc.ClassDocumenter):
 
     def format_name(self):
         path = find_service_path(self.env, self.object)
+        if path is None:
+            return
         return '/' + '/'.join(path)
 
 
@@ -490,8 +492,8 @@ class FunctionDocumenter(autodoc.MethodDocumenter):
 
     @staticmethod
     def can_document_member(member, membername, isattr, parent):
-        return (isinstance(parent, ServiceDocumenter)
-                and wsme.api.iswsmefunction(member))
+        return (isinstance(parent, ServiceDocumenter) and
+                wsme.api.iswsmefunction(member))
 
     def import_object(self):
         ret = super(FunctionDocumenter, self).import_object()
@@ -560,9 +562,11 @@ class WSMEDomain(Domain):
     }
 
     def clear_doc(self, docname):
-        for name, value in self.data['types'].items():
+        keys = list(self.data['types'].keys())
+        for key in keys:
+            value = self.data['types'][key]
             if value == docname:
-                del self.data['types'][name]
+                del self.data['types'][key]
 
     def resolve_xref(self, env, fromdocname, builder,
                      type, target, node, contnode):
