@@ -28,6 +28,7 @@ class XDecimal(suds.xsd.sxbuiltin.XBuiltin):
                 return str(value)
             return value
 
+
 suds.xsd.sxbuiltin.Factory.tags['decimal'] = XDecimal
 
 
@@ -83,6 +84,7 @@ class SudsCache(suds.cache.Cache):
     def clear(self, id):
         self.d = {}
 
+
 sudscache = SudsCache()
 
 tns = "http://foo.bar.baz/soap/"
@@ -200,6 +202,7 @@ def tosuds(client, value):
 def read_bool(value):
     return value == 'true'
 
+
 soap_types = {
     'xs:string': wsme.types.text,
     'xs:int': int,
@@ -244,6 +247,7 @@ def tobin(value):
     value = base64.decodestring(value.encode())
     return value
 
+
 fromsuds_types = {
     wsme.types.binary: tobin,
     wsme.types.bytes: tobytes,
@@ -397,7 +401,7 @@ class TestSOAP(wsme.tests.protocol.ProtocolTestCase):
 
         assert len(sd.ports) == 1
         port, methods = sd.ports[0]
-        self.assertEquals(len(methods), 49)
+        self.assertEqual(len(methods), 51)
 
         methods = dict(methods)
 
